@@ -9,12 +9,12 @@ module Config
   DESTDIR = '' if not defined? DESTDIR
   CONFIG = {}
   TOPDIR = File.dirname(__FILE__).sub!(%r'/lib/ruby/1\.6/i386\-mingw32\Z', '')
-  CONFIG["srcdir"] = "/pub/ruby/16/dist/ruby-1.6.8/ruby16"
+  CONFIG["srcdir"] = "/pub/ruby/16/ruby16"
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
   CONFIG["ruby_install_name"] = "ruby"
   CONFIG["EXEEXT"] = ".exe"
   CONFIG["SHELL"] = "/bin/sh"
-  CONFIG["CFLAGS"] = "-DNT -D__NO_ISOCEXT -Os"
+  CONFIG["CFLAGS"] = "-DNT -Os"
   CONFIG["CPPFLAGS"] = ""
   CONFIG["CXXFLAGS"] = ""
   CONFIG["FFLAGS"] = ""
@@ -79,7 +79,7 @@ module Config
   CONFIG["STRIP"] = "strip"
   CONFIG["EXTSTATIC"] = ""
   CONFIG["setup"] = "Setup"
-  CONFIG["MINIRUBY"] = "ruby -I/pub/ruby/16/dist/ruby-1.6.8/m.obj -rfake"
+  CONFIG["MINIRUBY"] = "ruby -I/pub/ruby/16/mingw -rfake"
   CONFIG["PREP"] = "fake.rb"
   CONFIG["LIBRUBY_LDSHARED"] = "dllwrap --target=mingw32 --as=as --dlltool-name=dlltool --driver-name=gcc -mno-cygwin --export-all -s"
   CONFIG["LIBRUBY_DLDFLAGS"] = "--dllname=$@ --output-lib=$(LIBRUBY) --add-stdcall-alias --def=$(RUBYDEF)"
@@ -88,7 +88,7 @@ module Config
   CONFIG["LIBRUBY_A"] = "lib$(RUBY_INSTALL_NAME)s.a"
   CONFIG["LIBRUBY_SO"] = "$(RUBY_SO_NAME).dll"
   CONFIG["LIBRUBY_ALIASES"] = ""
-  CONFIG["LIBRUBY"] = "lib$(RUBY_SO_NAME).a"
+  CONFIG["LIBRUBY"] = "lib$(LIBRUBY_SO).a"
   CONFIG["LIBRUBYARG"] = "-L. -l$(RUBY_SO_NAME)"
   CONFIG["SOLIBS"] = "$(LIBS)"
   CONFIG["DLDLIBS"] = ""
@@ -97,12 +97,14 @@ module Config
   CONFIG["arch"] = "i386-mingw32"
   CONFIG["sitedir"] = "$(prefix)/lib/ruby/site_ruby"
   CONFIG["configure_args"] = "--cache=config.cache --program-prefix= --target=i386-mingw32 --host=i686-pc-cygwin --build=i586-pc-linux-gnu --includedir=/usr/local/mingw/include --enable-shared --enable-tcltk_stubs --with-tcllib=tclstub83 --with-tklib=tkstub83 --with-dbm-type=gdbm --with-opt-dir=/usr/local/mingw"
+  CONFIG["NROFF"] = "/usr/bin/nroff"
+  CONFIG["MANTYPE"] = "doc"
   CONFIG["ruby_version"] = "$(MAJOR).$(MINOR)"
   CONFIG["rubylibdir"] = "$(libdir)/ruby/$(ruby_version)"
   CONFIG["archdir"] = "$(rubylibdir)/$(arch)"
   CONFIG["sitelibdir"] = "$(sitedir)/$(ruby_version)"
   CONFIG["sitearchdir"] = "$(sitelibdir)/$(arch)"
-  CONFIG["compile_dir"] = "/pub/ruby/16/dist/ruby-1.6.8/m.obj"
+  CONFIG["compile_dir"] = "/pub/ruby/16/mingw"
   MAKEFILE_CONFIG = {}
   CONFIG.each{|k,v| MAKEFILE_CONFIG[k] = v.dup}
   def Config::expand(val)
